import { useContext, useRef } from 'react';
import '../utils/useSealedState.js';
import '../utils/useId.js';
import { unstable_useCreateElement } from '../utils/useCreateElement.js';
import '../system/SystemContext.js';
import '../chunk-988837cf.js';
import '../chunk-56719312.js';
import { mergeProps } from '../utils/mergeProps.js';
import '../system/SystemProvider.js';
import { b as _objectSpread } from '../chunk-397c8002.js';
import { unstable_createComponent } from '../utils/createComponent.js';
import '../system/useToken.js';
import { unstable_useProps } from '../system/useProps.js';
import { unstable_useOptions } from '../system/useOptions.js';
import '../system/mergeSystem.js';
import '../Box/Box.js';
import '../chunk-6e18ef4b.js';
import '../Tabbable/Tabbable.js';
import '../chunk-29332083.js';
import { a as warning } from '../chunk-e555b6ea.js';
import 'react-dom';
import '../Portal/Portal.js';
import '../Hidden/HiddenState.js';
import '../Hidden/Hidden.js';
import '../Dialog/Dialog.js';
import 'body-scroll-lock';
import '../chunk-b4d83ecc.js';
import '../Dialog/DialogState.js';
import '../Rover/RoverState.js';
import '../Rover/Rover.js';
import { unstable_useKeyBinder } from '../KeyBinder/KeyBinder.js';
import 'popper.js';
import '../Popover/PopoverState.js';
import { usePopover } from '../Popover/Popover.js';
import { useStaticMenu } from './StaticMenu.js';
import { a as MenuContext } from '../chunk-ee62c270.js';
import { useMenuState } from './MenuState.js';

function useMenu(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var parent = useContext(MenuContext);
  var parentIsHorizontal = parent && parent.orientation === "horizontal";
  var ref = useRef(null);

  var _options = _objectSpread({
    unstable_autoFocusOnShow: !parent,
    unstable_autoFocusOnHide: !parentIsHorizontal
  }, options);

  _options = unstable_useOptions("Menu", _options, htmlProps);
  var isHorizontal = _options.orientation === "horizontal";
  var isVertical = _options.orientation === "vertical";
  var rovingBindings = unstable_useKeyBinder({
    stopPropagation: function stopPropagation(event) {
      // On Esc, only stop propagation if there's no parent menu
      // Otherwise, pressing Esc should close all menus
      if (event.key === "Escape" && parent) return false;
      return true;
    },
    keyMap: function keyMap(event) {
      var targetIsMenu = event.target === ref.current;
      return {
        Escape: _options.hide,
        ArrowUp: targetIsMenu && !isHorizontal && _options.last,
        ArrowRight: targetIsMenu && !isVertical && _options.first,
        ArrowDown: targetIsMenu && !isHorizontal && _options.first,
        ArrowLeft: targetIsMenu && !isVertical && _options.last,
        Home: targetIsMenu && _options.first,
        End: targetIsMenu && _options.last,
        PageUp: targetIsMenu && _options.first,
        PageDown: targetIsMenu && _options.last
      };
    }
  });
  var parentBindings = unstable_useKeyBinder({
    stopPropagation: true,
    keyMap: function keyMap() {
      var _options2 = _options,
          hide = _options2.hide,
          placement = _options2.placement;
      if (!parent || !hide || !placement) return {};
      var horizontalParent = parent;

      while (horizontalParent && horizontalParent.orientation !== "horizontal") {
        horizontalParent = horizontalParent.parent;
      }

      var _placement$split = placement.split("-"),
          dir = _placement$split[0];

      return {
        ArrowRight: horizontalParent && dir !== "left" ? horizontalParent.next : dir === "left" && hide,
        ArrowLeft: horizontalParent && dir !== "right" ? horizontalParent.previous : dir === "right" && hide
      };
    }
  });
  htmlProps = mergeProps({
    ref: ref,
    role: "menu",
    onKeyDown: function onKeyDown(event) {
      rovingBindings.onKeyDown(event);
      parentBindings.onKeyDown(event);
    }
  }, htmlProps);
  htmlProps = unstable_useProps("Menu", _options, htmlProps);
  htmlProps = useStaticMenu(_options, htmlProps);
  htmlProps = usePopover(_objectSpread({}, _options, {
    modal: false,
    unstable_portal: false,
    hideOnEsc: false
  }), htmlProps);
  return htmlProps;
}
var keys = [].concat(usePopover.__keys, useStaticMenu.__keys, useMenuState.__keys);
useMenu.__keys = keys;
var Menu = unstable_createComponent({
  as: "div",
  useHook: useMenu,
  useCreateElement: function useCreateElement(type, props, children) {
    process.env.NODE_ENV !== "production" ? warning(!props["aria-label"] && !props["aria-labelledby"], "You should provide either `aria-label` or `aria-labelledby` props.\nSee https://www.w3.org/TR/wai-aria-practices-1.1/#wai-aria-roles-states-and-properties-13", "Menu") : void 0;
    return unstable_useCreateElement(type, props, children);
  }
});

export { Menu, useMenu };
