import { useContext, useRef, useState, useEffect } from 'react';
import '../utils/useSealedState.js';
import '../utils/useId.js';
import '../utils/useCreateElement.js';
import '../system/SystemContext.js';
import '../chunk-988837cf.js';
import '../chunk-56719312.js';
import { mergeProps } from '../utils/mergeProps.js';
import '../system/SystemProvider.js';
import { b as _objectSpread } from '../chunk-397c8002.js';
import { unstable_createComponent } from '../utils/createComponent.js';
import '../system/useToken.js';
import { unstable_useProps } from '../system/useProps.js';
import { unstable_useOptions } from '../system/useOptions.js';
import '../system/mergeSystem.js';
import '../Box/Box.js';
import '../chunk-6e18ef4b.js';
import '../Tabbable/Tabbable.js';
import '../Button/Button.js';
import '../chunk-e555b6ea.js';
import '../Hidden/HiddenState.js';
import '../chunk-b4d83ecc.js';
import '../Dialog/DialogState.js';
import '../Hidden/HiddenDisclosure.js';
import '../Dialog/DialogDisclosure.js';
import '../Rover/RoverState.js';
import '../Rover/Rover.js';
import { unstable_useKeyBinder } from '../KeyBinder/KeyBinder.js';
import 'popper.js';
import '../Popover/PopoverState.js';
import { a as MenuContext } from '../chunk-ee62c270.js';
import { useMenuState } from './MenuState.js';
import { usePopoverDisclosure } from '../Popover/PopoverDisclosure.js';

function useMenuDisclosure(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var parent = useContext(MenuContext);
  var ref = useRef(null); // This avoids race condition between focus and click.
  // On some browsers, focus is triggered right before click.
  // So we use it to disable toggling.

  var _React$useState = useState(false),
      hasShownOnFocus = _React$useState[0],
      setHasShownOnFocus = _React$useState[1];

  options = unstable_useOptions("MenuDisclosure", options, htmlProps);
  var dir = options.placement ? options.placement.split("-")[0] : undefined; // Restores hasShownOnFocus

  useEffect(function () {
    if (hasShownOnFocus) {
      setTimeout(function () {
        return setHasShownOnFocus(false);
      }, 200);
    }
  }, [hasShownOnFocus]);

  var _unstable_useKeyBinde = unstable_useKeyBinder({
    stopPropagation: function stopPropagation(event) {
      return event.key !== "Escape";
    },
    onKey: options.show,
    keyMap: {
      Escape: options.hide,
      Enter: parent && options.first,
      " ": parent && options.first,
      ArrowUp: dir === "top" || dir === "bottom" ? options.last : false,
      ArrowRight: dir === "right" && options.first,
      ArrowDown: dir === "bottom" || dir === "top" ? options.first : false,
      ArrowLeft: dir === "left" && options.first
    }
  }),
      onKeyDown = _unstable_useKeyBinde.onKeyDown;

  htmlProps = mergeProps({
    ref: ref,
    "aria-haspopup": "menu",
    onFocus: function onFocus() {
      if (parent && parent.orientation === "horizontal") {
        setHasShownOnFocus(true);
        options.show();
      }
    },
    onMouseOver: function onMouseOver() {
      if (!parent || !options.placement) return;
      var parentIsHorizontal = parent.orientation === "horizontal";

      if (!parentIsHorizontal) {
        setTimeout(function () {
          if (ref.current && ref.current.contains(document.activeElement)) {
            options.show();
            ref.current.focus();
          }
        }, 200);
      } else if (ref.current) {
        var parentMenu = ref.current.closest("[role=menu],[role=menubar]");
        var subjacentOpenMenu = parentMenu && parentMenu.querySelector("[role=menu][aria-hidden=false]");

        if (subjacentOpenMenu) {
          ref.current.focus();
        }
      }
    },
    onKeyDown: onKeyDown
  }, htmlProps);
  htmlProps = unstable_useProps("MenuDisclosure", options, htmlProps);
  htmlProps = usePopoverDisclosure(_objectSpread({}, options, {
    toggle: parent && (parent.orientation !== "horizontal" || hasShownOnFocus) ? options.show : options.toggle
  }), htmlProps);
  return htmlProps;
}
var keys = [].concat(usePopoverDisclosure.__keys, useMenuState.__keys);
useMenuDisclosure.__keys = keys;
var MenuDisclosure = unstable_createComponent({
  as: "button",
  useHook: useMenuDisclosure
});

export { MenuDisclosure, useMenuDisclosure };
