'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
require('../utils/useSealedState.js');
require('../utils/useId.js');
var useCreateElement = require('../utils/useCreateElement.js');
require('../system/SystemContext.js');
require('../chunk-8e8e1bad.js');
require('../chunk-2138b837.js');
var mergeProps = require('../utils/mergeProps.js');
require('../system/SystemProvider.js');
var __chunk_3 = require('../chunk-37dea005.js');
var createComponent = require('../utils/createComponent.js');
require('../system/useToken.js');
var useProps = require('../system/useProps.js');
var useOptions = require('../system/useOptions.js');
require('../system/mergeSystem.js');
require('../Box/Box.js');
require('../chunk-9263130a.js');
require('../Tabbable/Tabbable.js');
require('../chunk-d4f443f9.js');
var __chunk_6 = require('../chunk-ebc3ed80.js');
require('react-dom');
require('../Portal/Portal.js');
require('../Hidden/HiddenState.js');
require('../Hidden/Hidden.js');
require('../Dialog/Dialog.js');
require('body-scroll-lock');
require('../chunk-5a603fe6.js');
require('../Dialog/DialogState.js');
require('../Rover/RoverState.js');
require('../Rover/Rover.js');
var KeyBinder = require('../KeyBinder/KeyBinder.js');
require('popper.js');
require('../Popover/PopoverState.js');
var Popover = require('../Popover/Popover.js');
var StaticMenu = require('./StaticMenu.js');
var __chunk_13 = require('../chunk-8a7a2ea8.js');
var MenuState = require('./MenuState.js');

function useMenu(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var parent = React.useContext(__chunk_13.MenuContext);
  var parentIsHorizontal = parent && parent.orientation === "horizontal";
  var ref = React.useRef(null);

  var _options = __chunk_3._objectSpread({
    unstable_autoFocusOnShow: !parent,
    unstable_autoFocusOnHide: !parentIsHorizontal
  }, options);

  _options = useOptions.unstable_useOptions("Menu", _options, htmlProps);
  var isHorizontal = _options.orientation === "horizontal";
  var isVertical = _options.orientation === "vertical";
  var rovingBindings = KeyBinder.unstable_useKeyBinder({
    stopPropagation: function stopPropagation(event) {
      // On Esc, only stop propagation if there's no parent menu
      // Otherwise, pressing Esc should close all menus
      if (event.key === "Escape" && parent) return false;
      return true;
    },
    keyMap: function keyMap(event) {
      var targetIsMenu = event.target === ref.current;
      return {
        Escape: _options.hide,
        ArrowUp: targetIsMenu && !isHorizontal && _options.last,
        ArrowRight: targetIsMenu && !isVertical && _options.first,
        ArrowDown: targetIsMenu && !isHorizontal && _options.first,
        ArrowLeft: targetIsMenu && !isVertical && _options.last,
        Home: targetIsMenu && _options.first,
        End: targetIsMenu && _options.last,
        PageUp: targetIsMenu && _options.first,
        PageDown: targetIsMenu && _options.last
      };
    }
  });
  var parentBindings = KeyBinder.unstable_useKeyBinder({
    stopPropagation: true,
    keyMap: function keyMap() {
      var _options2 = _options,
          hide = _options2.hide,
          placement = _options2.placement;
      if (!parent || !hide || !placement) return {};
      var horizontalParent = parent;

      while (horizontalParent && horizontalParent.orientation !== "horizontal") {
        horizontalParent = horizontalParent.parent;
      }

      var _placement$split = placement.split("-"),
          dir = _placement$split[0];

      return {
        ArrowRight: horizontalParent && dir !== "left" ? horizontalParent.next : dir === "left" && hide,
        ArrowLeft: horizontalParent && dir !== "right" ? horizontalParent.previous : dir === "right" && hide
      };
    }
  });
  htmlProps = mergeProps.mergeProps({
    ref: ref,
    role: "menu",
    onKeyDown: function onKeyDown(event) {
      rovingBindings.onKeyDown(event);
      parentBindings.onKeyDown(event);
    }
  }, htmlProps);
  htmlProps = useProps.unstable_useProps("Menu", _options, htmlProps);
  htmlProps = StaticMenu.useStaticMenu(_options, htmlProps);
  htmlProps = Popover.usePopover(__chunk_3._objectSpread({}, _options, {
    modal: false,
    unstable_portal: false,
    hideOnEsc: false
  }), htmlProps);
  return htmlProps;
}
var keys = [].concat(Popover.usePopover.__keys, StaticMenu.useStaticMenu.__keys, MenuState.useMenuState.__keys);
useMenu.__keys = keys;
var Menu = createComponent.unstable_createComponent({
  as: "div",
  useHook: useMenu,
  useCreateElement: function useCreateElement$1(type, props, children) {
    process.env.NODE_ENV !== "production" ? __chunk_6.warning(!props["aria-label"] && !props["aria-labelledby"], "You should provide either `aria-label` or `aria-labelledby` props.\nSee https://www.w3.org/TR/wai-aria-practices-1.1/#wai-aria-roles-states-and-properties-13", "Menu") : void 0;
    return useCreateElement.unstable_useCreateElement(type, props, children);
  }
});

exports.Menu = Menu;
exports.useMenu = useMenu;
