'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
require('../utils/useSealedState.js');
require('../utils/useId.js');
require('../utils/useCreateElement.js');
require('../system/SystemContext.js');
require('../chunk-8e8e1bad.js');
require('../chunk-2138b837.js');
var mergeProps = require('../utils/mergeProps.js');
require('../system/SystemProvider.js');
var __chunk_3 = require('../chunk-37dea005.js');
var createComponent = require('../utils/createComponent.js');
require('../system/useToken.js');
var useProps = require('../system/useProps.js');
var useOptions = require('../system/useOptions.js');
require('../system/mergeSystem.js');
require('../Box/Box.js');
require('../chunk-9263130a.js');
require('../Tabbable/Tabbable.js');
require('../Button/Button.js');
require('../chunk-ebc3ed80.js');
require('../Hidden/HiddenState.js');
require('../chunk-5a603fe6.js');
require('../Dialog/DialogState.js');
require('../Hidden/HiddenDisclosure.js');
require('../Dialog/DialogDisclosure.js');
require('../Rover/RoverState.js');
require('../Rover/Rover.js');
var KeyBinder = require('../KeyBinder/KeyBinder.js');
require('popper.js');
require('../Popover/PopoverState.js');
var __chunk_13 = require('../chunk-8a7a2ea8.js');
var MenuState = require('./MenuState.js');
var PopoverDisclosure = require('../Popover/PopoverDisclosure.js');

function useMenuDisclosure(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var parent = React.useContext(__chunk_13.MenuContext);
  var ref = React.useRef(null); // This avoids race condition between focus and click.
  // On some browsers, focus is triggered right before click.
  // So we use it to disable toggling.

  var _React$useState = React.useState(false),
      hasShownOnFocus = _React$useState[0],
      setHasShownOnFocus = _React$useState[1];

  options = useOptions.unstable_useOptions("MenuDisclosure", options, htmlProps);
  var dir = options.placement ? options.placement.split("-")[0] : undefined; // Restores hasShownOnFocus

  React.useEffect(function () {
    if (hasShownOnFocus) {
      setTimeout(function () {
        return setHasShownOnFocus(false);
      }, 200);
    }
  }, [hasShownOnFocus]);

  var _unstable_useKeyBinde = KeyBinder.unstable_useKeyBinder({
    stopPropagation: function stopPropagation(event) {
      return event.key !== "Escape";
    },
    onKey: options.show,
    keyMap: {
      Escape: options.hide,
      Enter: parent && options.first,
      " ": parent && options.first,
      ArrowUp: dir === "top" || dir === "bottom" ? options.last : false,
      ArrowRight: dir === "right" && options.first,
      ArrowDown: dir === "bottom" || dir === "top" ? options.first : false,
      ArrowLeft: dir === "left" && options.first
    }
  }),
      onKeyDown = _unstable_useKeyBinde.onKeyDown;

  htmlProps = mergeProps.mergeProps({
    ref: ref,
    "aria-haspopup": "menu",
    onFocus: function onFocus() {
      if (parent && parent.orientation === "horizontal") {
        setHasShownOnFocus(true);
        options.show();
      }
    },
    onMouseOver: function onMouseOver() {
      if (!parent || !options.placement) return;
      var parentIsHorizontal = parent.orientation === "horizontal";

      if (!parentIsHorizontal) {
        setTimeout(function () {
          if (ref.current && ref.current.contains(document.activeElement)) {
            options.show();
            ref.current.focus();
          }
        }, 200);
      } else if (ref.current) {
        var parentMenu = ref.current.closest("[role=menu],[role=menubar]");
        var subjacentOpenMenu = parentMenu && parentMenu.querySelector("[role=menu][aria-hidden=false]");

        if (subjacentOpenMenu) {
          ref.current.focus();
        }
      }
    },
    onKeyDown: onKeyDown
  }, htmlProps);
  htmlProps = useProps.unstable_useProps("MenuDisclosure", options, htmlProps);
  htmlProps = PopoverDisclosure.usePopoverDisclosure(__chunk_3._objectSpread({}, options, {
    toggle: parent && (parent.orientation !== "horizontal" || hasShownOnFocus) ? options.show : options.toggle
  }), htmlProps);
  return htmlProps;
}
var keys = [].concat(PopoverDisclosure.usePopoverDisclosure.__keys, MenuState.useMenuState.__keys);
useMenuDisclosure.__keys = keys;
var MenuDisclosure = createComponent.unstable_createComponent({
  as: "button",
  useHook: useMenuDisclosure
});

exports.MenuDisclosure = MenuDisclosure;
exports.useMenuDisclosure = useMenuDisclosure;
