'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
require('../utils/useSealedState.js');
require('../utils/useId.js');
var useCreateElement = require('../utils/useCreateElement.js');
require('../system/SystemContext.js');
require('../chunk-8e8e1bad.js');
require('../chunk-2138b837.js');
var mergeProps = require('../utils/mergeProps.js');
require('../chunk-37dea005.js');
var createComponent = require('../utils/createComponent.js');
require('../system/useToken.js');
var useProps = require('../system/useProps.js');
var useOptions = require('../system/useOptions.js');
var Box = require('../Box/Box.js');
require('../chunk-9263130a.js');
require('../Tabbable/Tabbable.js');
var __chunk_6 = require('../chunk-ebc3ed80.js');
require('../Hidden/HiddenState.js');
require('../chunk-5a603fe6.js');
require('../Dialog/DialogState.js');
require('../Rover/RoverState.js');
require('../Rover/Rover.js');
require('popper.js');
require('../Popover/PopoverState.js');
var __chunk_13 = require('../chunk-8a7a2ea8.js');
var MenuState = require('./MenuState.js');

function useShortcuts(_ref, timeout) {
  var stops = _ref.stops,
      move = _ref.move;

  if (timeout === void 0) {
    timeout = 500;
  }

  var _React$useState = React.useState(""),
      keys = _React$useState[0],
      setKeys = _React$useState[1];

  React.useEffect(function () {
    if (!keys) return undefined;
    var timeoutId = setTimeout(function () {
      return setKeys("");
    }, timeout);
    var stop = stops.find(function (s) {
      return Boolean(s.ref.current && s.ref.current.textContent && s.ref.current.textContent.toLowerCase().startsWith(keys));
    });

    if (stop) {
      move(stop.id);
    }

    return function () {
      return clearTimeout(timeoutId);
    };
  }, [keys, stops, move]);
  return function (event) {
    if (event.metaKey || event.altKey || event.shiftKey || event.ctrlKey) {
      return;
    }

    if (/^[a-z0-9_-]$/i.test(event.key)) {
      event.stopPropagation();
      event.preventDefault();
      setKeys("" + keys + event.key);
    }
  };
}

function useStaticMenu(options, htmlProps) {
  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var parent = React.useContext(__chunk_13.MenuContext);
  options = useOptions.unstable_useOptions("StaticMenu", options, htmlProps);
  var providerValue = React.useMemo(function () {
    return {
      orientation: options.orientation,
      next: options.next,
      previous: options.previous,
      parent: parent
    };
  }, [options.orientation, options.next, options.previous, parent]);
  var onKeyDown = useShortcuts(options);
  htmlProps = mergeProps.mergeProps({
    role: options.orientation === "horizontal" ? "menubar" : "menu",
    "aria-orientation": options.orientation,
    onKeyDown: onKeyDown,
    unstable_wrap: function unstable_wrap(children) {
      return React.createElement(__chunk_13.MenuContext.Provider, {
        value: providerValue
      }, children);
    }
  }, htmlProps);
  htmlProps = useProps.unstable_useProps("StaticMenu", options, htmlProps);
  htmlProps = Box.useBox(options, htmlProps);
  return htmlProps;
}
var keys = [].concat(Box.useBox.__keys, MenuState.useMenuState.__keys);
useStaticMenu.__keys = keys;
var StaticMenu = createComponent.unstable_createComponent({
  as: "div",
  useHook: useStaticMenu,
  useCreateElement: function useCreateElement$1(type, props, children) {
    process.env.NODE_ENV !== "production" ? __chunk_6.warning(!props["aria-label"] && !props["aria-labelledby"] && props.role !== "menubar", "You should provide either `aria-label` or `aria-labelledby` props.\nSee https://www.w3.org/TR/wai-aria-practices-1.1/#wai-aria-roles-states-and-properties-13", "Menu") : void 0;
    return useCreateElement.unstable_useCreateElement(type, props, children);
  }
});

exports.StaticMenu = StaticMenu;
exports.useStaticMenu = useStaticMenu;
