'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
require('../utils/useSealedState.js');
var useId = require('../utils/useId.js');
require('../utils/useCreateElement.js');
require('../system/SystemContext.js');
require('../chunk-8e8e1bad.js');
require('../chunk-2138b837.js');
var mergeProps = require('../utils/mergeProps.js');
var __chunk_3 = require('../chunk-37dea005.js');
var createComponent = require('../utils/createComponent.js');
require('../system/useToken.js');
var useProps = require('../system/useProps.js');
var useOptions = require('../system/useOptions.js');
require('../Box/Box.js');
require('../chunk-9263130a.js');
var Tabbable = require('../Tabbable/Tabbable.js');
require('../chunk-ebc3ed80.js');
var __chunk_7 = require('../chunk-5a603fe6.js');
var RoverState = require('./RoverState.js');

function useRover(options, _ref) {
  if (_ref === void 0) {
    _ref = {};
  }

  var _ref2 = _ref,
      tabIndex = _ref2.tabIndex,
      _onKeyDown = _ref2.onKeyDown,
      htmlProps = __chunk_3._objectWithoutPropertiesLoose(_ref2, ["tabIndex", "onKeyDown"]);

  options = useOptions.unstable_useOptions("Rover", options, htmlProps);
  var ref = React.useRef(null);
  var id = useId.unstable_useId("rover-");
  var stopId = options.stopId || htmlProps.id || id;
  var reallyDisabled = options.disabled && !options.focusable;
  var noFocused = options.currentId == null;
  var focused = options.currentId === stopId;
  var isFirst = options.stops[0] && options.stops[0].id === stopId;
  var shouldTabIndex = focused || isFirst && noFocused;
  React.useEffect(function () {
    if (reallyDisabled) return undefined;
    options.register(stopId, ref);
    return function () {
      return options.unregister(stopId);
    };
  }, [stopId, reallyDisabled, options.register, options.unregister]);
  __chunk_7.useUpdateEffect(function () {
    if (ref.current && focused) {
      ref.current.focus();
    }
  }, [focused]);
  htmlProps = mergeProps.mergeProps({
    ref: ref,
    id: stopId,
    tabIndex: shouldTabIndex ? tabIndex : -1,
    onFocus: function onFocus() {
      return options.move(stopId);
    },
    onKeyDown: function onKeyDown(event) {
      var _options = options,
          orientation = _options.orientation;
      var keyMap = {
        ArrowUp: orientation !== "horizontal" && options.previous,
        ArrowRight: orientation !== "vertical" && options.next,
        ArrowDown: orientation !== "horizontal" && options.next,
        ArrowLeft: orientation !== "vertical" && options.previous,
        Home: options.first,
        End: options.last,
        PageUp: options.first,
        PageDown: options.last
      };

      if (event.key in keyMap) {
        var key = event.key;
        var action = keyMap[key];

        if (action) {
          event.preventDefault();
          action(); // Prevent onKeyDown from being called twice for the same keys.

          return;
        }
      }

      if (_onKeyDown) {
        _onKeyDown(event);
      }
    }
  }, htmlProps);
  htmlProps = useProps.unstable_useProps("Rover", options, htmlProps);
  htmlProps = Tabbable.useTabbable(options, htmlProps);
  return htmlProps;
}
var keys = [].concat(Tabbable.useTabbable.__keys, RoverState.useRoverState.__keys, ["stopId"]);
useRover.__keys = keys;
var Rover = createComponent.unstable_createComponent({
  as: "button",
  useHook: useRover
});

exports.Rover = Rover;
exports.useRover = useRover;
