import * as React from "react";
import { HiddenOptions, HiddenProps } from "../Hidden/Hidden";
import { DialogStateReturn } from "./DialogState";
export declare type DialogOptions = HiddenOptions & Pick<Partial<DialogStateReturn>, "hide"> & Pick<DialogStateReturn, "unstable_hiddenId"> & {
    /**
     * Toggles Dialog's `modal` state.
     *  - Non-modal: `preventBodyScroll` doesn't work and focus is free.
     *  - Modal: `preventBodyScroll` is automatically enabled, focus is
     * trapped within the dialog and the dialog is rendered within a `Portal`
     * by default.
     */
    modal?: boolean;
    /**
     * When enabled, user can hide the dialog by pressing `Escape`.
     */
    hideOnEsc?: boolean;
    /**
     * When enabled, user can hide the dialog by clicking outside it.
     */
    hideOnClickOutside?: boolean;
    /**
     * When enabled, user can't scroll on body when the dialog is visible.
     * This option doesn't work if the dialog isn't modal.
     */
    preventBodyScroll?: boolean;
    /**
     * The element that will be focused when the dialog shows.
     * When not set, the first tabbable element within the dialog will be used.
     * `autoFocusOnShow` disables it.
     */
    unstable_initialFocusRef?: React.RefObject<HTMLElement>;
    /**
     * The element that will be focused when the dialog hides.
     * When not set, the disclosure component will be used.
     * `autoFocusOnHide` disables it.
     */
    unstable_finalFocusRef?: React.RefObject<HTMLElement>;
    /**
     * Whether or not the dialog should be rendered within `Portal`.
     * It's `true` by default if `modal` is `true`.
     */
    unstable_portal?: boolean;
    /**
     * Whether or not to move focus when the dialog shows.
     * @private
     */
    unstable_autoFocusOnShow?: boolean;
    /**
     * Whether or not to move focus when the dialog hides.
     * @private
     */
    unstable_autoFocusOnHide?: boolean;
};
export declare type DialogProps = HiddenProps;
export declare function useDialog({ modal, hideOnEsc, hideOnClickOutside, preventBodyScroll, unstable_autoFocusOnShow, unstable_autoFocusOnHide, unstable_portal: isPortal, ...options }: DialogOptions, htmlProps?: DialogProps): import("..").BoxProps;
export declare namespace useDialog {
    var __keys: ("unstable_system" | "unstable_hiddenId" | "show" | "hide" | "visible" | "toggle" | "modal" | "hideOnEsc" | "hideOnClickOutside" | "preventBodyScroll" | "unstable_initialFocusRef" | "unstable_finalFocusRef" | "unstable_portal" | "unstable_autoFocusOnShow" | "unstable_autoFocusOnHide")[];
}
export declare const Dialog: import("../utils/createComponent").Component<"div", DialogOptions>;
