import * as React from "react";
import { unstable_SealedInitialState } from "../utils/useSealedState";
import { DialogState, DialogActions, DialogInitialState } from "../Dialog/DialogState";
declare type Placement = "auto-start" | "auto" | "auto-end" | "top-start" | "top" | "top-end" | "right-start" | "right" | "right-end" | "bottom-end" | "bottom" | "bottom-start" | "left-end" | "left" | "left-start";
export declare type PopoverState = DialogState & {
    /**
     * The reference element.
     */
    unstable_referenceRef: React.RefObject<HTMLElement | null>;
    /**
     * The popover element.
     * @private
     */
    unstable_popoverRef: React.RefObject<HTMLElement | null>;
    /**
     * The arrow element.
     * @private
     */
    unstable_arrowRef: React.RefObject<HTMLElement | null>;
    /**
     * Popover styles.
     * @private
     */
    unstable_popoverStyles: Partial<CSSStyleDeclaration>;
    /**
     * Arrow styles.
     * @private
     */
    unstable_arrowStyles: Partial<CSSStyleDeclaration>;
    /**
     * `placement` passed to the hook.
     * @private
     */
    unstable_originalPlacement: Placement;
    /**
     * Actual `placement`.
     */
    placement: Placement;
};
export declare type PopoverActions = DialogActions & {
    /**
     * Change the `placement` state.
     */
    place: React.Dispatch<React.SetStateAction<Placement>>;
};
export declare type PopoverInitialState = DialogInitialState & Partial<Pick<PopoverState, "placement">> & {
    /**
     * Whether or not flip the popover.
     */
    unstable_flip?: boolean;
    /**
     * Whether or not shift the popover.
     */
    unstable_shift?: boolean;
    /**
     * Offset between the reference and the popover.
     */
    unstable_gutter?: number;
};
export declare type PopoverStateReturn = PopoverState & PopoverActions;
export declare function usePopoverState(initialState?: unstable_SealedInitialState<PopoverInitialState>): PopoverStateReturn;
export declare namespace usePopoverState {
    var __keys: ("unstable_referenceRef" | "unstable_hiddenId" | "show" | "hide" | "visible" | "unstable_popoverRef" | "unstable_arrowRef" | "unstable_popoverStyles" | "unstable_arrowStyles" | "unstable_originalPlacement" | "placement" | "toggle" | "place")[];
}
export {};
